Discover Packages
github.com/241x/zero-web
response
package
Version:
v0.0.8
Opens a new window with list of versions in this module.
Published: Jun 24, 2026
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Error 输出错误响应
优先解析 *apperror.Error,提取错误码和消息;未识别的错误兜底为 Internal
type Response struct {
ErrCode int `json:"errcode"`
Message string `json:"message"`
Data any `json:"data"`
Cost string `json:"cost"`
TraceId string `json:"traceId"`
}
Response 响应数据结构体
Source Files
¶
Click to show internal directories.
Click to hide internal directories.